# Lime Sample Dataset: `Simple` 

This has two question sheets, each with two questions. 

The questions are simple and should be solveable by any LLM.

On `input-common-sense-2.md` the second question has incorrect ground-truth for demonstration pruposes.
